/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010-2012 University of Bonn. All rights reserved.
 * Copyright (C)  2013 Frederik Heber. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * ElementsCommandLineQuery.cpp
 *
 *  Created on: Oct 25, 2010
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include <string>

#include "CommandLineUI/Query/CommandLineQuery.hpp"
#include "CommandLineUI/CommandLineParser.hpp"
#include "CodePatterns/Log.hpp"
#include "CodePatterns/Verbose.hpp"
#include "Element/element.hpp"
#include "Element/periodentafel.hpp"
#include "World.hpp"

CommandLineDialog::ElementsCommandLineQuery::ElementsCommandLineQuery(Parameter<std::vector<const element*> > &_param, const std::string &_title, const std::string &_description) :
    Dialog::TQuery<std::vector<const element *> >(_param, _title, _description)
{}

CommandLineDialog::ElementsCommandLineQuery::~ElementsCommandLineQuery()
{}

template <typename T>
std::vector<const element *> getElementsFromInput(const std::vector<std::string> &_input)
{
  periodentafel *periode = World::getInstance().getPeriode();
  std::vector<const element *> result;
  const element *temp_element;
  for (typename std::vector<std::string>::const_iterator ZRunner = _input.begin(); ZRunner != _input.end(); ++ZRunner) {
    const T argument = boost::lexical_cast<T>(*ZRunner);
    temp_element = periode->FindElement(argument);
    ASSERT(temp_element != NULL, "Invalid element specified in ElementCommandLineQuery");
    result.push_back(temp_element);
  }
  return result;
}

bool CommandLineDialog::ElementsCommandLineQuery::handle() {
  // TODO: vector of ints and removing first is not correctly implemented yet. How to remove from a vector?
  if (CommandLineParser::getInstance().vm.count(getTitle())) {
    try {
      std::vector<std::string> AllArguments;
      AllArguments = CommandLineParser::getInstance().vm[getTitle()].as< vector<std::string> >();
      try {
        temp = getElementsFromInput<int>(AllArguments);
      } catch(boost::bad_lexical_cast &e) {
        try {
        temp = getElementsFromInput<std::string>(AllArguments);
        } catch(boost::bad_lexical_cast &e) {
          return false;
        }
      }
    } catch(boost::bad_any_cast &e) {
      return false;
    }
    if (temp.empty())
      return false;
    else
      return true;
  }
  return false;
}

